package org.apache.commons.lang3.concurrent.locks;

import java.util.Objects;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import java.util.concurrent.locks.StampedLock;
import java.util.function.Supplier;
import org.apache.commons.lang3.function.FailableConsumer;
import org.apache.commons.lang3.function.FailableFunction;

public class LockingVisitors {

    public static class LockVisitor<O, L> {
        private final L lock;
        private final O object;
        private final Supplier<Lock> readLockSupplier;
        private final Supplier<Lock> writeLockSupplier;

        protected LockVisitor(O o, L l, Supplier<Lock> supplier, Supplier<Lock> supplier2) {
            this.object = (O) Objects.requireNonNull(o, "object");
            this.lock = (L) Objects.requireNonNull(l, "lock");
            this.readLockSupplier = (Supplier) Objects.requireNonNull(supplier, "readLockSupplier");
            this.writeLockSupplier = (Supplier) Objects.requireNonNull(supplier2, "writeLockSupplier");
        }

        public void acceptReadLocked(FailableConsumer<O, ?> failableConsumer) {
            lockAcceptUnlock(this.readLockSupplier, failableConsumer);
        }

        public void acceptWriteLocked(FailableConsumer<O, ?> failableConsumer) {
            lockAcceptUnlock(this.writeLockSupplier, failableConsumer);
        }

        public <T> T applyReadLocked(FailableFunction<O, T, ?> failableFunction) {
            return (T) lockApplyUnlock(this.readLockSupplier, failableFunction);
        }

        public <T> T applyWriteLocked(FailableFunction<O, T, ?> failableFunction) {
            return (T) lockApplyUnlock(this.writeLockSupplier, failableFunction);
        }

        public L getLock() {
            return this.lock;
        }

        public O getObject() {
            return this.object;
        }

        public void lockAcceptUnlock(Supplier<Lock> supplier, FailableConsumer<O, ?> failableConsumer) {
            Lock lock2 = supplier.get();
            lock2.lock();
            try {
                failableConsumer.accept(this.object);
                lock2.unlock();
            } catch (Throwable th) {
                lock2.unlock();
                throw th;
            }
        }

        public <T> T lockApplyUnlock(Supplier<Lock> supplier, FailableFunction<O, T, ?> failableFunction) {
            Lock lock2 = supplier.get();
            lock2.lock();
            try {
                T apply = failableFunction.apply(this.object);
                lock2.unlock();
                return apply;
            } catch (Throwable th) {
                lock2.unlock();
                throw th;
            }
        }
    }

    public static class ReadWriteLockVisitor<O> extends LockVisitor<O, ReadWriteLock> {
        /* JADX WARNING: Illegal instructions before constructor call */
        protected ReadWriteLockVisitor(O o, ReadWriteLock readWriteLock) {
            super(o, readWriteLock, r0, new LockingVisitors$ReadWriteLockVisitor$$ExternalSyntheticLambda1(readWriteLock));
            readWriteLock.getClass();
            LockingVisitors$ReadWriteLockVisitor$$ExternalSyntheticLambda0 lockingVisitors$ReadWriteLockVisitor$$ExternalSyntheticLambda0 = new LockingVisitors$ReadWriteLockVisitor$$ExternalSyntheticLambda0(readWriteLock);
            readWriteLock.getClass();
        }
    }

    public static class StampedLockVisitor<O> extends LockVisitor<O, StampedLock> {
        /* JADX WARNING: Illegal instructions before constructor call */
        protected StampedLockVisitor(O o, StampedLock stampedLock) {
            super(o, stampedLock, r0, new LockingVisitors$StampedLockVisitor$$ExternalSyntheticLambda1(stampedLock));
            stampedLock.getClass();
            LockingVisitors$StampedLockVisitor$$ExternalSyntheticLambda0 lockingVisitors$StampedLockVisitor$$ExternalSyntheticLambda0 = new LockingVisitors$StampedLockVisitor$$ExternalSyntheticLambda0(stampedLock);
            stampedLock.getClass();
        }
    }

    public static <O> ReadWriteLockVisitor<O> reentrantReadWriteLockVisitor(O o) {
        return new ReadWriteLockVisitor<>(o, new ReentrantReadWriteLock());
    }

    public static <O> StampedLockVisitor<O> stampedLockVisitor(O o) {
        return new StampedLockVisitor<>(o, new StampedLock());
    }
}
